@@ -18,16 +18,16 @@
 # All functions dedicated to manage the files.
 #
 
-unmount_tmp_dir()
-{
-	if [ -n "$mount_point" ] && 
-	   [ -d $mount_point ] &&
-	   [ grep $mount_point /etc/mtab >/dev/null 2>&1 ]; then
-		umount "$mount_point" > /dev/null 2>&1 || error "unable to unmount \$mount_point"
-		sleep 1
-		rmdir "$mount_point" > /dev/null 2>&1 || error "unable to remove \$mount_point"
-	fi
-}
+#unmount_tmp_dir()
+#{
+#	if [ -n "$mount_point" ] && 
+#	   [ -d $mount_point ] &&
+#	   [ grep $mount_point /etc/mtab >/dev/null 2>&1 ]; then
+#		umount "$mount_point" > /dev/null 2>&1 || error "unable to unmount \$mount_point"
+#		sleep 1
+#		rmdir "$mount_point" > /dev/null 2>&1 || error "unable to remove \$mount_point"
+#	fi
+#}
 
 # this will send the appropriate name of archive to 
 # make according to what the user choose in the conf.
@@ -63,38 +63,29 @@ get_dir_name()
 
 # This will take a path and return the size in mega bytes
 # used on the disk.
+# Thanks to Michel Grentzinger <mic.grentz@online.fr>
 size_of_path()
 {
 	path="$1"
     if [ -z "$path" ]; then
-        error "No path given"
+        error "No path given."
     fi
-    
-	out=$(du -m -c $path)
 
-	OLDIFS=$IFS
-	IFS=$'\n'
-	# The last size seen is the total.
-	for line in $out
-	do
-		total_size=$(echo $line | awk '{print $1}')
-	done
-	IFS=$OLDIFS
+    #echo "DEBUG: du --si --block-size=1000k -c $path | tail -1 | awk '{print $1}'" >&2
+    total_size=$(du --si --block-size=1000k -c $path | tail -1 | awk '{print $1}')
 	echo $total_size
 }
 
+# Thanks to Michel Grentzinger <mic.grentz@online.fr>
 size_left_of_path()
 {
 	path="$1"
-	out=$(df -B 1024K $path) 
+    if [ -z "$path" ]; then
+        error "No path given."
+    fi
+
+	left=$(df --si --block-size=1000k "$path" | tail -1 | awk '{print $4}')
 
-	OLDIFS=$IFS
-	IFS=$'\n'
-	for line in $out
-	do
-		left=$(echo $line | awk '{print $4}')
-	done
-	IFS=$OLDIFS
 	echo $left
 
 }
@@ -111,17 +102,12 @@ get_prefix_from_file()
 # Will return the date contained in the file name
 get_date_from_file()
 {
-    filename="$1"
-    date_string="20[0-9][0-9][0-1][0-9][0-3][0-9]"
-    case "$filename" in 
-        *-*${date_string}.[!-]* ) 
-            __tmp="${filename#${filename%${date_string}*}}}"; 
-            echo "${__tmp%%.*}"; 
-        ;; 
-        *) 
-            echo ""
-        ;;
-    esac
+	filename="$1"
+	date=$(echo $filename | sed -e 's/.*\([0-9]\{8\}\).*/\1/')
+	if [ $date = $filename ] ; then
+		date=""
+	fi
+	echo $date
 }
 
 # This function is here to free each lock previously enabled.
@@ -167,7 +153,7 @@ get_lock() {
 			if [ -z $real_pid ]; then
 				echo_translated "Removing lock for old PID, \$pid is not running."
 				release_lock
-				unmount_tmp_dir
+				#unmount_tmp_dir
 				pid=""
 			fi
 		fi
@@ -188,7 +174,7 @@ get_lock() {
 		info "Getting lock for backup-manager \$pid with \$conffile"
 		echo "$$ $conffile " > $lockfile
 		if [ ! -e $lockfile ]; then
-			error "failed (check the file permissions)"
+			error "failed (check the file permissions)."
 			exit 1
 		fi
 	fi
@@ -207,16 +193,14 @@ clean_file()
 	fi
 
 	date=$(get_date_from_file $file)
-	if [ -n "$date" ] && [ "$date" != "$file" ]; then
-	    date=$(echo $date | sed -e 's/[^0-9]//g')
-    	if [ ! -z $date ]; then
-    		if [ $date -lt $date_to_remove ] || 
-    		   [ $date = $date_to_remove ]; then
-    			info "Removing \$file"
-    			rm -f $file
-    		fi
-    	fi
-    fi
+	date=$(echo $date | sed -e 's/[^0-9]//g')
+	if [ ! -z $date ]; then
+		if [ $date -lt $date_to_remove ] || 
+		   [ $date = $date_to_remove ]; then
+			info "Removing \$file"
+			rm -f $file
+		fi
+	fi
 }
 
 # clean one given repository.
@@ -230,7 +214,7 @@ clean_directory()
 	directory="$1"
 
 	if [ ! -d $directory ]; then
-		error "Directory given is not found"
+		error "Directory given is not found."
 	fi
 
 	for file in $directory/*
@@ -240,7 +224,7 @@ clean_directory()
 		fi
 		
 		if [ -d $file ]; then
-			info "Entering directory \$file."
+			info "Entering directory \$file"
 			clean_directory "$file"
 		else 
 			clean_file "$file"
@@ -255,11 +239,6 @@ clean_directory()
 purge_duplicate_archives()
 {
 	file_to_create="$1"
-    if [ ! -e $file_to_create ]; then
-        error "No such file \$file_to_create"
-        return 1
-    fi    
-	size_file=$(ls -l $file_to_create | awk '{print $5}')
 
 	# Only purge if BM_ARCHIVE_PURGEDUPS = true
 	if [ -z "$BM_ARCHIVE_PURGEDUPS" ] ||
@@ -267,26 +246,29 @@ purge_duplicate_archives()
 		return 0
 	fi
 
-	if [ -z "$file_to_create" ]; then
-		error "No file given"
-	fi
+    if [ ! -e $file_to_create ]; then
+        error "The given file does not exist: \$file_to_create"
+        return 1
+    fi    
 
-	if [ ! -e $file_to_create ]; then
-		error "The given file does not exist: \$file_to_create"
+	if [ -z "$file_to_create" ]; then
+		error "No file given."
 	fi
 
 	# we'll parse all the files of the same source
-	date_of_file=$(get_date_from_file $file_to_create) || error "unable to get date from file"
-	file_pattern=$(echo $file_to_create | sed -e "s/$date_of_file.*$//") || error "unable to find the pattern of the file"
+	date_of_file=$(get_date_from_file $file_to_create) || 
+        error "Unable to get date from file."
+	file_pattern=$(echo $file_to_create | sed -e "s/$date_of_file.*$/\*/") || 
+        error "Unable to find the pattern of the file."
 	
-	for file in $file_pattern*
+	for file in $file_pattern
 	do
 		if [ ! -L $file ] && 
 		   [ "$file" != "$file_to_create" ]; then
-			size=$(ls -l $file | awk '{print $5}')
+			md5sum_to_check=$(get_md5sum_from_file $file_to_create $BM_REPOSITORY_ROOT/${BM_ARCHIVE_PREFIX}-${TODAY}.md5)
 
-			if [ "$size_file" = "$size" ]; then
-				info "\$file is a duplicate of \$file_to_create (using symlink)"
+			if [ "$md5hash" = "$md5sum_to_check" ]; then
+				info "\$file is a duplicate of \$file_to_create (using symlink)."
 				rm -f $file
 				ln -s $file_to_create $file
 			fi
