@@ -24,7 +24,8 @@ if [ -e $BM_ARCHIVE_ROOT ]; then
 fi    
 
 bm_init_env
-create_archive_root_if_not_exists
+bm_init_today
+create_directories
 make_archives
 
 name=$(get_dir_name $PWD long)
