@@ -16,7 +16,8 @@ source confs/upload-rsync.conf
 
 # The test actions
 bm_init_env
-create_archive_root_if_not_exists
+bm_init_today
+create_directories
 make_archives
 upload_files
 
