@@ -17,7 +17,8 @@ export BM_BURNING_METHOD="none"
 
 # The test actions
 bm_init_env
-create_archive_root_if_not_exists
+bm_init_today
+create_directories
 make_archives
 upload_files
 burn_files
